# Gemini TTS (немесе Gemini Parrot TTS) - Қарапайым мәтіннен сөйлеуге айналдыру кітапханасы

Бұл кітапхана Google Gemini API арқылы мәтінді сөйлеуге айналдыруға арналған **креативті шешім**. Ол Gemini моделін тек берілген мәтінді қайталауға ("тотықұс" режимі) бағыттауға тырысады, бірақ модельдің сұхбаттасуға бейімділігіне байланысты бұл әрдайым толық орындалмауы мүмкін.

## Орнату (Installation)

### Pip арқылы орнату (болашақта)
```bash
# Негізгі функционалдылық
pip install gemini-tts

# Аудио ойнату қолдауымен (ұсынылады)
pip install gemini-tts[audio]
```

### Кодтан орнату
```bash
git clone https://github.com/dauitsuragan002/gemini-tts.git
cd gemini-tts
pip install -e .
# Аудио ойнату үшін
pip install -e .[audio]
```

## Қажетті компоненттер
- Python 3.7+
- websockets
- wave
- pygame (опционалды, аудио ойнату үшін)

## Қолдану (Usage)

### 1. Класс арқылы қолдану (ұсынылған әдіс)
```python
from gemini_tts import GeminiTTS

# Клиент жасау
client = GeminiTTS(api_key="your_api_key_here", default_voice="Puck")

# Сөйлеуге айналдыру және аудио файлын сақтау
client.say("Бұл класс арқылы жасалған мысал")

# Дауыс түрін өзгерту
client.say("Бұл басқа дауыс", voice="Kore")

# Аудионы ойнатпау
client.say("Тек файлға сақтау", play_audio=False)
```

### 3. Аудионы тікелей ойнату
```python
from gemini_tts import GeminiTTS

client = GeminiTTS(api_key="your_api_key_here")

# Мәтінді сөйлеуге айналдыру және бірден ойнату
client.say("Бұл дыбыс автоматты түрде ойнатылады", play_audio=True)
```

### 4. Синхронды түрде файл генерациялау (ойнатпау)
```python
from gemini_tts import GeminiTTS

client = GeminiTTS(api_key="your_api_key_here")

# Мәтінді сөйлеуге айналдыру, бірақ ойнатпау
file_path = client.text_to_speech("Бұл тек файлға сақталады", output_file="sync_output.wav")
print(f"Аудио файл синхронды түрде сақталды: {file_path}")
```

**Ескерту:** Gemini TTS (кейде "Gemini Parrot TTS" деп те атауға болады) арқылы төмендегі дауыстар әрдайым дәлме-дәл дыбысталмауы мүмкін. Себебі, бұл кітапхана Gemini моделін тек мәтінді қайталауға ("тотықұс" режимі) "мәжбүрлеуге" тырысады, бірақ модель кейде бәрібір сұхбаттасуға көшіп, енгізілген мәтінге жауап беруі ықтимал. Бұл – осы креативті әдістің белгілі бір шектеуі.

## Толық мысалдар

- `example.py` - негізгі функцияларды көрсетеді
- `/voice_example` - әр түрлі дауыспен аудиоға түрлендірген аудиолар 

## Дауыс түрлері
Gemini API ұсынатын кейбір дауыс түрлері:
- **Ерлер дауыстары:**
  - Charon (жуан)
  - Puck
  - Fenrir
- **Әйелдер дауыстары:**
  - Kore
  - Aoede

## Нұсқа тарихы

### v0.1.1
- Тікелей аудио ойнату қосылды
- Дауыс параметрлерін оңтайландыру (жуан ерлер дауыстары үшін)
- Дауыстарды категориялар бойынша ұйымдастыру
- Тотықұс ЖИ

### v0.1.0
- Алғашқы нұсқа

## Авторлар
- Әзірлеуші: David Suragan
- AI көмекші: Claude (Anthropic)

## Алғыс білдіру
Бұл жоба [agituts/gemini-2-tts](https://github.com/agituts/gemini-2-tts) репозиторийінен шабыт алды. Осы жобаның авторына шексіз алғысымызды білдіреміз.

## Лицензия
MIT
